==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/order_total/ot_total.php <==
<?php
/*
  $Id: ot_total.php,v 1.1.1.1 2005/06/30 05:04:20 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

  class ot_total {
    var $title, $output;

    function ot_total() {
      $this->code = 'ot_total';
      $this->title = MODULE_ORDER_TOTAL_TOTAL_TITLE;
      $this->description = MODULE_ORDER_TOTAL_TOTAL_DESCRIPTION;
      $this->enabled = ((MODULE_ORDER_TOTAL_TOTAL_STATUS == 'true') ? true : false);
      $this->sort_order = MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER;

      $this->output = array();
    }

    function process() {
      global $order, $currencies;
      global $payment;
      global $HTTP_POST_VARS;

      $total = $order->info['total'];
      if ((MODULE_ORDER_TOTAL_CODT_STATUS == 'true')
// BOF koshoten.net-2.0.2
// ޥȡ͹׹Խб
/*
          && ($payment == 'cod_table')
*/
          && (($payment == 'cod_table') || ($payment == 'cod_table_sagawaex') || ($payment == 'cod_table_yamato') || ($payment == 'cod_table_yuupack'))
// EOF koshoten.net-2.0.2
          && isset($HTTP_POST_VARS['codt_fee'])
          && (0 < intval($HTTP_POST_VARS['codt_fee']))) {
        $total += intval($HTTP_POST_VARS['codt_fee']);
      }

      $this->output[] = array('title' => $this->title . ':',
                              'text' => '<b>' . $currencies->format($total, true, $order->info['currency'], $order->info['currency_value']) . '</b>',
                              'value' => $total);
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_ORDER_TOTAL_TOTAL_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }

      return $this->_check;
    }

    function keys() {
      return array('MODULE_ORDER_TOTAL_TOTAL_STATUS', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER');
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('׳ۤɽ', 'MODULE_ORDER_TOTAL_TOTAL_STATUS', 'true', '׳ۤɽ򤷤ޤ?', '6', '1','tep_cfg_select_option(array(\'true\', \'false\'), ', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER', '6', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '2', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }
  }
?>

==> koshoten.net-2.1.5.tar.gz: koshoten-net/catalog/includes/modules/order_total/ot_total.php <==
<?php
/*
  $Id: ot_total.php,v 1.2 2006/01/29 14:49:24 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/

  class ot_total {
    var $title, $output;

    function ot_total() {
      $this->code = 'ot_total';
      $this->title = MODULE_ORDER_TOTAL_TOTAL_TITLE;
      $this->description = MODULE_ORDER_TOTAL_TOTAL_DESCRIPTION;
      $this->enabled = ((MODULE_ORDER_TOTAL_TOTAL_STATUS == 'true') ? true : false);
      $this->sort_order = MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER;

      $this->output = array();
    }

    function process() {
      global $order, $currencies;
      global $payment;
      global $HTTP_POST_VARS;

      $total = $order->info['total'];
/* 
      if ((MODULE_ORDER_TOTAL_CODT_STATUS == 'true')
          && ($payment == 'cod_table')
          && isset($HTTP_POST_VARS['codt_fee'])
          && (0 < intval($HTTP_POST_VARS['codt_fee']))) {
        $total += intval($HTTP_POST_VARS['codt_fee']);
      }
*/
      if (isset($_SESSION['codt_fee'])) { $codt_fee = $_SESSION['codt_fee']; }
      if ((MODULE_ORDER_TOTAL_CODT_STATUS == 'true')
          && (($payment == 'cod_table') || ($payment == 'cod_table_sagawaex') || ($payment == 'cod_table_yamato') || ($payment == 'cod_table_yuupack') || ($payment == 'cod_table_nipponex'))
          && isset($codt_fee)
          && (0 < intval($codt_fee))) {
        $total += intval($codt_fee);
      }

      $this->output[] = array('title' => $this->title . ':',
                              'text' => '<b>' . $currencies->format($total, true, $order->info['currency'], $order->info['currency_value']) . '</b>',
                              'value' => $total);
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_ORDER_TOTAL_TOTAL_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }

      return $this->_check;
    }

    function keys() {
      return array('MODULE_ORDER_TOTAL_TOTAL_STATUS', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER');
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('׳ۤɽ', 'MODULE_ORDER_TOTAL_TOTAL_STATUS', 'true', '׳ۤɽ򤷤ޤ?', '6', '1','tep_cfg_select_option(array(\'true\', \'false\'), ', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER', '6', 'ɽǤޤ. ۤɾ̤ɽޤ.', '6', '2', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }
  }
?>
